==> google_cloud_dataproc-0.4.0-py2.py3-none-any.whl: google/cloud/dataproc_v1beta2/gapic/transports/autoscaling_policy_service_grpc_transport.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import google.api_core.grpc_helpers

from google.cloud.dataproc_v1beta2.proto import autoscaling_policies_pb2_grpc


class AutoscalingPolicyServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.dataproc.v1beta2 AutoscalingPolicyService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self, channel=None, credentials=None, address="dataproc.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(address=address, credentials=credentials)

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            "autoscaling_policy_service_stub": autoscaling_policies_pb2_grpc.AutoscalingPolicyServiceStub(
                channel
            )
        }

    @classmethod
    def create_channel(cls, address="dataproc.googleapis.com:443", credentials=None):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def create_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.create_autoscaling_policy`.

        Creates new autoscaling policy.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].CreateAutoscalingPolicy

    @property
    def update_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.update_autoscaling_policy`.

        Updates (replaces) autoscaling policy.

        Disabled check for update\_mask, because all updates will be full
        replacements.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].UpdateAutoscalingPolicy

    @property
    def get_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.get_autoscaling_policy`.

        Retrieves autoscaling policy.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].GetAutoscalingPolicy

    @property
    def list_autoscaling_policies(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.list_autoscaling_policies`.

        Lists autoscaling policies in the project.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].ListAutoscalingPolicies

    @property
    def delete_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.delete_autoscaling_policy`.

        Deletes an autoscaling policy. It is an error to delete an autoscaling
        policy that is in use by one or more clusters.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].DeleteAutoscalingPolicy

==> google_cloud_dataproc-0.5.0-py2.py3-none-any.whl: google/cloud/dataproc_v1beta2/gapic/transports/autoscaling_policy_service_grpc_transport.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import google.api_core.grpc_helpers

from google.cloud.dataproc_v1beta2.proto import autoscaling_policies_pb2_grpc


class AutoscalingPolicyServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.cloud.dataproc.v1beta2 AutoscalingPolicyService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """

    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    def __init__(
        self, channel=None, credentials=None, address="dataproc.googleapis.com:443"
    ):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                "The `channel` and `credentials` arguments are mutually " "exclusive."
            )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(address=address, credentials=credentials)

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            "autoscaling_policy_service_stub": autoscaling_policies_pb2_grpc.AutoscalingPolicyServiceStub(
                channel
            )
        }

    @classmethod
    def create_channel(
        cls, address="dataproc.googleapis.com:443", credentials=None, **kwargs
    ):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address, credentials=credentials, scopes=cls._OAUTH_SCOPES, **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def create_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.create_autoscaling_policy`.

        Creates new autoscaling policy.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].CreateAutoscalingPolicy

    @property
    def update_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.update_autoscaling_policy`.

        Updates (replaces) autoscaling policy.

        Disabled check for update\_mask, because all updates will be full
        replacements.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].UpdateAutoscalingPolicy

    @property
    def get_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.get_autoscaling_policy`.

        Retrieves autoscaling policy.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].GetAutoscalingPolicy

    @property
    def list_autoscaling_policies(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.list_autoscaling_policies`.

        Lists autoscaling policies in the project.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].ListAutoscalingPolicies

    @property
    def delete_autoscaling_policy(self):
        """Return the gRPC stub for :meth:`AutoscalingPolicyServiceClient.delete_autoscaling_policy`.

        Deletes an autoscaling policy. It is an error to delete an autoscaling
        policy that is in use by one or more clusters.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs["autoscaling_policy_service_stub"].DeleteAutoscalingPolicy
